add — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# add

Poscar.add(position: ndarray, element: str, direct: bool = True, selectiveFlags: ndarray | None = None)

  Adds one atom to the class. Only one atom at the time

  Parameters:

    - position (np.ndarray) – (3 or 1x3) the positions of new atom

    - element (str) – Name of the element of the new atom

    - direct (bool) – are the positions given direct (True) or Cartesian (False) coordinates? Default is True

    - selectiveFlags (np.ndarray(str)) – only of self.selective == True